# Overview
- Use [Taskfile](https://taskfile.dev) to manage the project's CLI
- Use [Dev Container](https://code.visualstudio.com/docs/devcontainers/containers) to create a development environment
- https://www.yuque.com/lwmacct/vscode/dev-containers
```shell
task -a
```

# Related Links
- https://github.com/lwmacct